package com.nartosoft.picuploader;

import java.awt.Color;
import java.awt.Font;
import java.io.File;
import java.io.FileInputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import java.util.StringTokenizer;

/**
 * @author eb, mf
 * 
 * Provides easy access to the configuration of PicUplader.
 */

public class FileConfiguration implements Configuration {
	
	public static final String PROXY_COMMAND = "proxy";

	public static final String LOGFILE_COMMAND = "logFile";

	public static final String LOGFILEFORMAT_COMMAND = "logParameters";

	public static final String TEMPLATE_COMMAND = "templateName";

	public static final String VERBOSE_SWITCH = "verbose";

	public static final String HTMLFILE_COMMAND = "historyFileName";

	public static final String SUMMARY_COMMAND = "summary";

	public static final String SOUND_COMMAND = "soundFileName";

	public static final String AUTOSCALE_COMMAND = "autoscale";
 
	public static final String TRAYICON_COMMAND = "trayicon";
	
	public static final String SCREENSHOT_COMMAND = "screenshot";
	
	public static final String SHOWSCREENSHOTDIALOG_SWITCH = "showgui";
	
	public static final String WATERMARK_COMMAND = "watermark";
	
	public static final String WATERMARK_XOR = "xor";
	
	public static final String WATERMARK_YOR = "yor";
	
	public static final String WATERMARK_FONTFACE = "fontface";
	
	public static final String WATERMARK_FONTSIZE = "fontsize";
	
	public static final String WATERMARK_FONTCOLOR = "fontcolor";
	

	private static final String CONFIGURATIONPATH = "./configurations/";
	
	 
	private Properties props=null;
	
	private String[] args = null;


	public FileConfiguration(String[] args) {
		try {
		  this.props = new Properties();
		  this.args = (String[])args.clone();
		  File f = new File(CONFIGURATIONPATH + args[0]);
		  FileInputStream fs = new FileInputStream(f);
		  this.props.load(fs);
		}catch(Exception e) {
			e.printStackTrace();
		}
	}


	public boolean isProxySet() {
		return props.containsKey(PROXY_COMMAND);
	}

	public boolean isLogFileSet() {
		return props.containsKey(LOGFILE_COMMAND);
	}

	public boolean isLogFileFormatSet() {
		return props.containsKey(LOGFILEFORMAT_COMMAND);
	}

	public boolean isHtmlFileSet() {
		return props.containsKey(HTMLFILE_COMMAND);
	}

	public boolean isTemplateSet() {
		return props.containsKey(TEMPLATE_COMMAND);
	}

	public boolean isSummarySet() {
		return props.containsKey(SUMMARY_COMMAND);
	}

	public boolean isSoundSet() {
		return props.containsKey(SOUND_COMMAND);
	}

	public boolean isAutoscaleSet() {
		return props.containsKey(AUTOSCALE_COMMAND);
	}

	public boolean isTrayiconSet() {
		return props.containsKey(TRAYICON_COMMAND);
	}
	
	public boolean isScreenshotSet() {
		return props.containsKey(SCREENSHOT_COMMAND);
	}
	
	public boolean isShowGUISet() {
		return props.containsKey(SHOWSCREENSHOTDIALOG_SWITCH);
	}
	
	public int getMaxFileSize() {
		if (isAutoscaleSet()) {
			return Integer.parseInt((String) props.get(AUTOSCALE_COMMAND));
		}
		else {
			return -1;
		}
	}
	
	public boolean isWatermarkSet() {
		return props.containsKey(WATERMARK_COMMAND);
	}

	public String getSoundFile() {
		return (String) props.get(SOUND_COMMAND);
	}

	public boolean isVerboseSet() {
		return props.containsKey(VERBOSE_SWITCH);
	}

	public String getProxy() {
		return (String) props.get(PROXY_COMMAND);
	}

	public String getLogFileName() {
		return (String) props.get(LOGFILE_COMMAND);
	}

	public String getSummaryTime() {
		return (String) props.get(SUMMARY_COMMAND);
	}

	public String getTrayiconFile() {
		return (String)props.get(TRAYICON_COMMAND);
	}
	
	public int getScreenshotDelay() {
		String s = (String)props.get(SCREENSHOT_COMMAND);
		if(s!=null) {
			return Integer.parseInt(s);
		}
		else {
			return 0;
		}
	}
	
	private String getLogFileFormat() {
		if (isLogFileFormatSet()) {
			return ((String) props.get(LOGFILEFORMAT_COMMAND)).toLowerCase();
		}
		else {
			return "";
		}
	}

	public boolean isImageFileLoggingSet() {
		return getLogFileFormat().indexOf('i') >= 0;
	}

	public boolean isUrlLoggingSet() {
		return getLogFileFormat().indexOf('u') >= 0;
	}

	public boolean isErrorLoggingSet() {
		return getLogFileFormat().indexOf('e') >= 0;
	}

	public String getTemplateFileName() {
		return (String) props.get(TEMPLATE_COMMAND);
	}

	public String getHtmlFileName() {
		return (String) props.get(HTMLFILE_COMMAND);
	}
	
    public String getWatermarkText() {
    	return (String)props.get(WATERMARK_COMMAND);
    }
    
    public int getWatermarkXor() {
    	return Integer.parseInt((String)props.get(WATERMARK_XOR));
    }
    
    public int getWatermarkYor() {
    	return Integer.parseInt((String)props.get(WATERMARK_YOR));
    }
    
    public Font getWatermarkFont() {
    	return new Font((String)props.get(WATERMARK_FONTFACE), Font.PLAIN, Integer.parseInt((String)props.getProperty(WATERMARK_FONTSIZE)));
    }
    
    public Color getWatermarkColor() {
      String cs = (String)props.getProperty(WATERMARK_FONTCOLOR);
      StringTokenizer st = new StringTokenizer(cs, ",");
      int r = Integer.parseInt(st.nextToken());
      int g = Integer.parseInt(st.nextToken());
      int b = Integer.parseInt(st.nextToken());
      int a = Integer.parseInt(st.nextToken());
      Color c = new Color(r,g,b,a);
      return c;
    }

	/**
	 * Returns the template string read from the template file, or null if either
	 * no template file was set or an error occured while reading it.
	 */
	public String getTemplate() {
		if (!isTemplateSet()) {
			return null;
		}
		return Utils.readFile(getTemplateFileName());
	}


	public List getFileNames() {
		List list = new ArrayList();
		for (int i = 1; i < args.length; i++) {
		  list.add(args[i]);
		}
		return list;

	}

}
