package com.nartosoft.picuploader;

import java.awt.BasicStroke;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Robot;
import java.awt.Stroke;
import java.awt.Toolkit;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.geom.Line2D;
import java.awt.image.BufferedImage;
import java.io.File;
import java.util.Iterator;
import java.util.Vector;

import javax.imageio.ImageIO;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

// TODO: provide ScreenshotCheckPanel with target filename instead of generating one
// TODO: rename class, it's not only relevant for screenshots!

public class ScreenshotCheckPanel extends JPanel implements MouseListener,
		MouseMotionListener, KeyListener {

	private BufferedImage theImage = null;

	private int oldXPos;

	private int oldYPos;

	private Rectangle currRect;

	private Vector allRect;
	
	private Vector allLines;

	private Rectangle clipRect;

	private String savedImageName;
	
	private JDialog mainDialog;
	
	public ScreenshotCheckPanel() {
		this.allRect = new Vector();
		this.allLines = new Vector();
		this.addMouseListener(this);
		this.addMouseMotionListener(this);
		this.addKeyListener(this);
		this.setFocusable(true);
		savedImageName = null;
	}

	public ScreenshotCheckPanel(JDialog mainDialog) {
		this();
		this.mainDialog = mainDialog;
	}

	public void setImage(BufferedImage image) {
		if (image != null) {
			this.setSize(image.getWidth(), image.getHeight());
			this.setPreferredSize(new Dimension(image.getWidth(), image.getHeight()));
			this.setLocation(0, 0);
			this.theImage = image;
		}
		repaint();
	}

	public String getSavedImageName() {
		return this.savedImageName;
	}

	protected void paintComponent(Graphics g) {
		super.paintComponents(g);
		g.drawImage(theImage, 0, 0, this);
		g.setColor(Color.BLACK);
		// g.setXORMode(Color.BLACK);
		fillRect(g, currRect);
		Iterator it = this.allRect.iterator();
		while (it.hasNext()) {
			fillRect(g, (Rectangle) it.next());
		}
		g.setColor(Color.RED);
		it = this.allLines.iterator();
		while(it.hasNext()) {
			drawLine(g, (Line2D) it.next());
		}
		drawClipRect(g);
		// g.setColor(Color.BLACK);
		// g.setFont(new Font("Arial", Font.BOLD, 30));
		// g.drawString("Screenshot: use Mouse to Clip, Strg + Mouse to censor,
		// Shift + Mouse to undo censor, Enter to send", 50,
		// 50);//this.getHeight()-50);
		this.requestFocus();
	}

	private void drawClipRect(Graphics g) {
		if (this.clipRect != null) {
			g.setColor(new Color(255, 0, 0, 25));
			fillRect(g, clipRect);
			g.setColor(Color.RED);
			g.drawRect(clipRect.x, clipRect.y, clipRect.width, clipRect.height);
		}
	}

	// / Draws a filled rectangle into g, using the currently set colour.
	private void fillRect(Graphics g, Rectangle rect) {
		if (g != null && rect != null) {
			g.fillRect(rect.x, rect.y, rect.width, rect.height);
		}
	}
	
	//Draws a line into g, using the currently set colour
	private void drawLine(Graphics g, Line2D l) {
		if(g !=null && l !=null) {
			Graphics2D g2d = (Graphics2D)g;
			Stroke s = g2d.getStroke();
			g2d.setStroke(new BasicStroke(5));
			g2d.drawLine((int)l.getX1(), (int)l.getY1(), (int)l.getX2(), (int)l.getY2());
			g2d.setStroke(s);
		}
	}

	public void mouseDragged(MouseEvent event) {
		if ((event.getModifiers() & (InputEvent.CTRL_MASK)) != 0) {
			updateCensorRect(event.getX(), event.getY());
		}
		else if((event.getModifiers() & (InputEvent.ALT_MASK)) != 0) {
			addLine(event.getX(), event.getY());
		}
		else {
			updateClipRect(event.getX(), event.getY());
		}
		repaint();
	}
	
	private void addLine(int x, int y) {
		this.allLines.add(new Line2D.Double(this.oldXPos, this.oldYPos, x, y));
		this.oldXPos = x;
		this.oldYPos = y;
	}

	private void updateClipRect(int x, int y) {
  	  clipRect = new Rectangle(new Point(Math.min(oldXPos, x), Math.min(oldYPos, y)));
	  clipRect.width = Math.abs(x-oldXPos);
	  clipRect.height = Math.abs(y-oldYPos);
	}

	private void updateCensorRect(int x, int y) {
      currRect = new Rectangle(new Point(Math.min(oldXPos, x), Math.min(oldYPos, y)));
	  currRect.width = Math.abs(x-oldXPos);
	  currRect.height = Math.abs(y-oldYPos);
	}

	public void mouseMoved(MouseEvent event) {
		this.oldXPos = event.getX();
		this.oldYPos = event.getY();
	}

	public void mouseClicked(MouseEvent event) {
		if ((event.getModifiers() & (InputEvent.SHIFT_MASK)) != 0) {
			removeRectAt(event.getPoint());
		}
		repaint();
	}

	private void removeRectAt(Point p) {
		Iterator it = this.allRect.iterator();
		while (it.hasNext()) {
			if (((Rectangle) it.next()).contains(p)) {
				it.remove();
			}
		}
	}

	public void mouseReleased(MouseEvent arg0) {
		if (currRect != null) {
			this.allRect.add(this.currRect);
			this.currRect = null;
			this.repaint();
		}
	}

	public void mouseEntered(MouseEvent arg0) {
	}

	public void mouseExited(MouseEvent arg0) {
	}

	public void mousePressed(MouseEvent arg0) {
	}

	public void keyPressed(KeyEvent arg0) {
	}

	public void keyReleased(KeyEvent arg0) {
		if (arg0.getKeyCode() == KeyEvent.VK_ENTER) {
			BufferedImage image = null;
			Graphics g = null;
			if (this.clipRect != null) {
				image = new BufferedImage(clipRect.width, clipRect.height,
						this.theImage.getType());
				g = image.getGraphics();
				g.translate(-clipRect.x, -clipRect.y);
				g.clipRect(clipRect.x, clipRect.y, clipRect.width, clipRect.height);

			}
			else {
				image = new BufferedImage(this.theImage.getWidth(), this.theImage
						.getHeight(), this.theImage.getType());
				g = image.getGraphics();
			}
			g.drawImage(theImage, 0, 0, this);
			g.setColor(Color.BLACK);
			fillRect(g, currRect);
			Iterator it = this.allRect.iterator();
			while (it.hasNext()) {
				fillRect(g, (Rectangle) it.next());
			}
			g.setColor(Color.RED);
			it = this.allLines.iterator();
			while (it.hasNext()) {
				drawLine(g, (Line2D) it.next());
			}

			try {
				File f = new File(".//screenshots//~" + System.currentTimeMillis() + ".png");
				ImageIO.write(image, "png", f);
				this.savedImageName = f.getAbsolutePath();
				mainDialog.hide();
				
			}
			catch (Exception e) {
				e.printStackTrace();
			}
		}
		else if (arg0.getKeyCode() == KeyEvent.VK_ESCAPE) {
			// close everything
		}
	}

	public void keyTyped(KeyEvent arg0) {
		if (arg0.getKeyChar() == 'c') {
			this.allRect.clear();
			this.allLines.clear();
			this.currRect = null;
			this.clipRect = null;
			repaint();
		}
	}

	public static void main(String[] args) {//only for testing!
		BufferedImage img;
		Toolkit toolkit = Toolkit.getDefaultToolkit();
		Dimension screenSize = toolkit.getScreenSize();
		try {
			Robot r = new Robot();
			img = r.createScreenCapture(new Rectangle(0,0,(int)screenSize.getWidth(), (int)screenSize.getHeight()));
		}
		catch (Exception e) {
			e.printStackTrace();
			return;
		}

		JFrame frame = new JFrame();
		frame.getContentPane().setLayout(new BorderLayout());


		frame.setSize(Math.min(img.getWidth(), (int) screenSize.getWidth()), Math
				.min(img.getHeight(), (int) screenSize.getHeight()));
		ScreenshotCheckPanel panel = new ScreenshotCheckPanel();
		panel.setImage(img);
		JScrollPane p = new JScrollPane(panel);
		frame.getContentPane().add(p);
		frame.setVisible(true);
	}

}
